module.exports=[33290,a=>{"use strict";var b=a.i(33256);function c({children:a}){return(0,b.jsx)("html",{lang:"en",children:(0,b.jsx)("body",{className:"antialiased",children:a})})}a.s(["default",()=>c,"metadata",0,{title:"Hibiki-Zero",description:"Kyutai's real-time speech translation model"}])}];

//# sourceMappingURL=app_layout_tsx_271801d7._.js.map