var R=require("../chunks/ssr/[turbopack]_runtime.js")("server/app/page.js")
R.c("server/chunks/ssr/[root-of-the-server]__40f96b4a._.js")
R.c("server/chunks/ssr/_01c4e054._.js")
R.c("server/chunks/ssr/_2ea50d3c._.js")
R.c("server/chunks/ssr/[root-of-the-server]__173d9339._.js")
R.c("server/chunks/ssr/[root-of-the-server]__18d33ef4._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_13536700._.js")
R.c("server/chunks/ssr/app_b9b1292a._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_builtin_global-error_e9f28481.js")
R.c("server/chunks/ssr/app_layout_tsx_271801d7._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_fe4d1120._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_builtin_forbidden_f38c7b3a.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_builtin_unauthorized_cfd039bd.js")
R.c("server/chunks/ssr/_next-internal_server_app_page_actions_39d4fc33.js")
R.m(80911)
module.exports=R.m(80911).exports
