var R=require("../../chunks/ssr/[turbopack]_runtime.js")("server/app/_not-found/page.js")
R.c("server/chunks/ssr/[root-of-the-server]__dd208065._.js")
R.c("server/chunks/ssr/_01c4e054._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_esm_build_templates_app-page_49154d6d.js")
R.c("server/chunks/ssr/[root-of-the-server]__3264198c._.js")
R.c("server/chunks/ssr/[root-of-the-server]__18d33ef4._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_13536700._.js")
R.c("server/chunks/ssr/app_b9b1292a._.js")
R.c("server/chunks/ssr/app_layout_tsx_271801d7._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_fe4d1120._.js")
R.c("server/chunks/ssr/b2b3e_next_dist_client_components_builtin_forbidden_f38c7b3a.js")
R.c("server/chunks/ssr/_next-internal_server_app__not-found_page_actions_554ec2bf.js")
R.m(64420)
module.exports=R.m(64420).exports
