module.exports=[85535,(a,b,c)=>{let{createClientModuleProxy:d}=a.r(48844);a.n(d("[project]/node_modules/.pnpm/next@16.1.6_@babel+core@7.29.0_react-dom@19.2.3_react@19.2.3__react@19.2.3/node_modules/next/dist/client/components/builtin/global-error.js <module evaluation>"))},64371,(a,b,c)=>{let{createClientModuleProxy:d}=a.r(48844);a.n(d("[project]/node_modules/.pnpm/next@16.1.6_@babel+core@7.29.0_react-dom@19.2.3_react@19.2.3__react@19.2.3/node_modules/next/dist/client/components/builtin/global-error.js"))},51548,a=>{"use strict";a.i(85535);var b=a.i(64371);a.n(b)}];

//# sourceMappingURL=b2b3e_next_dist_client_components_builtin_global-error_e9f28481.js.map