module.exports=[93695,(a,b,c)=>{b.exports=a.x("next/dist/shared/lib/no-fallback-error.external.js",()=>require("next/dist/shared/lib/no-fallback-error.external.js"))},70864,a=>{a.n(a.i(33290))},9014,a=>{a.n(a.i(70055))},79070,a=>{a.n(a.i(96918))},77303,a=>{a.n(a.i(77645))},5869,a=>{"use strict";a.s(["default",()=>b]);let b=(0,a.i(48844).registerClientReference)(function(){throw Error("Attempted to call the default export of [project]/app/page.tsx <module evaluation> from the server, but it's on the client. It's not possible to invoke a client function from the server, it can only be rendered as a Component or passed to props of a Client Component.")},"[project]/app/page.tsx <module evaluation>","default")},83897,a=>{"use strict";a.s(["default",()=>b]);let b=(0,a.i(48844).registerClientReference)(function(){throw Error("Attempted to call the default export of [project]/app/page.tsx from the server, but it's on the client. It's not possible to invoke a client function from the server, it can only be rendered as a Component or passed to props of a Client Component.")},"[project]/app/page.tsx","default")},50708,a=>{"use strict";a.i(5869);var b=a.i(83897);a.n(b)}];

//# sourceMappingURL=%5Broot-of-the-server%5D__40f96b4a._.js.map